( cd usr/lib ; rm -rf libieee1284.so )
( cd usr/lib ; ln -sf libieee1284.so.3.2.0 libieee1284.so )
( cd usr/lib ; rm -rf libieee1284.so.3 )
( cd usr/lib ; ln -sf libieee1284.so.3.2.0 libieee1284.so.3 )
